@@ -307,13 +307,14 @@ class StubEmitter:
     ):
         # recursively map a nested type annotation to match the output interface
         origin = getattr(type_annotation, "__origin__", None)
-        if origin is None:
+        args = getattr(type_annotation, "__args__", None)
+
+        if origin is None or args is None:
             # scalar - if type is synchronicity origin type, use the blocking/async version instead
             if synchronizer:
                 return synchronizer._translate_out(type_annotation, interface)
             return type_annotation
 
-        args = getattr(type_annotation, "__args__", [])
         mapped_args = tuple(
             self._translate_annotation(arg, synchronizer, interface, home_module)
             for arg in args
@@ -424,8 +425,9 @@ class StubEmitter:
         assert not isinstance(
             annotation, typing.ForwardRef
         )  # Forward refs should already have been evaluated!
+        args = getattr(annotation, "__args__", None)
 
-        if origin is None:
+        if origin is None or not args:
             if annotation == Ellipsis:
                 return "..."
             if isinstance(annotation, type) or isinstance(annotation, TypeVar):
@@ -441,19 +443,23 @@ class StubEmitter:
                 return annotation.__module__ + "." + name
             return repr(annotation)
         # generic:
-        args = getattr(annotation, "__args__", ())
-
-        formatted_annotation = str(
-            annotation.copy_with(
-                # ellipsis (...) needs to be passed as is, or it will be reformatted
-                tuple(
-                    ReprObj(self._formatannotation(arg))
-                    if arg != Ellipsis
-                    else Ellipsis
-                    for arg in args
+        try:
+            formatted_annotation = str(
+                annotation.copy_with(
+                    # ellipsis (...) needs to be passed as is, or it will be reformatted
+                    tuple(
+                        ReprObj(self._formatannotation(arg))
+                        if arg != Ellipsis
+                        else Ellipsis
+                        for arg in args
+                    )
                 )
             )
-        )
+        except Exception:
+            raise Exception(
+                f"Could not reformat generic {annotation.__origin__} with arguments {args}"
+            )
+
         # this is a bit ugly, but gets rid of incorrect module qualification of Generic subclasses:
         # TODO: find a better way...
         if formatted_annotation.startswith(self.target_module + "."):
@@ -477,7 +483,8 @@ class StubEmitter:
         else:
             root_func = func
 
-        for overload_func in overload_tracking.get_overloads(root_func):
+        overloaded_signatures = overload_tracking.get_overloads(root_func)
+        for overload_func in overloaded_signatures:
             self._ensure_import(typing.overload)
             parts.append(f"{signature_indent}@typing.overload")
             if interface:
@@ -489,9 +496,11 @@ class StubEmitter:
                 )
             )
 
-        parts.append(
-            self._get_function_source(func, name, signature_indent, body_indent)
-        )
+        if not overloaded_signatures:
+            # only add the functions complete signatures if there are no stubs
+            parts.append(
+                self._get_function_source(func, name, signature_indent, body_indent)
+            )
         return "\n".join(parts)
 
     def _get_function_source(
@@ -515,17 +524,17 @@ class StubEmitter:
 
 
 def write_stub(module_path: str):
-    mod = importlib.import_module(module_path)
-    assert mod.__file__ is not None
-    emitter = StubEmitter.from_module(mod)
-    source = emitter.get_source()
-    stub_path = Path(mod.__file__).with_suffix(".pyi")
-    stub_path.write_text(source)
-    return stub_path
+    with overload_tracking.patched_overload():
+        mod = importlib.import_module(module_path)
+        assert mod.__file__ is not None
+        emitter = StubEmitter.from_module(mod)
+        source = emitter.get_source()
+        stub_path = Path(mod.__file__).with_suffix(".pyi")
+        stub_path.write_text(source)
+        return stub_path
 
 
 if __name__ == "__main__":
-    with overload_tracking.patched_overload():
-        for module_path in sys.argv[1:]:
-            out_path = write_stub(module_path)
-            print(f"Wrote {out_path}")
+    for module_path in sys.argv[1:]:
+        out_path = write_stub(module_path)
+        print(f"Wrote {out_path}")
