@@ -1,8 +1,4 @@
-import asyncio
-import pytest
-from typing import Dict, Any
-
-from synchronicity import Interface, Synchronizer
+from synchronicity import Synchronizer
 
 
 def test_docs():
@@ -20,12 +16,12 @@ def test_docs():
     assert foo.__init__.__doc__ == "init docs"
     assert foo.bar.__doc__ == "bar docs"
 
-    BlockingFoo = s.create(Foo)[Interface.BLOCKING]
+    BlockingFoo = s.create_blocking(Foo)
     blocking_foo = BlockingFoo()
     assert blocking_foo.__init__.__doc__ == "init docs"
     assert blocking_foo.bar.__doc__ == "bar docs"
 
-    AsyncFoo = s.create(Foo)[Interface.ASYNC]
+    AsyncFoo = s.create_async(Foo)
     async_foo = AsyncFoo()
     assert async_foo.__init__.__doc__ == "init docs"
     assert async_foo.bar.__doc__ == "bar docs"
