@@ -1,4 +1,4 @@
-from synchronicity import Synchronizer, Interface
+from synchronicity import Synchronizer
 
 
 def test_function_sync():
@@ -7,5 +7,5 @@ def test_function_sync():
     async def f(x):
         return x**2
 
-    f_blocking = s.create(f)[Interface.BLOCKING]
+    f_blocking = s.create_blocking(f)
     assert f_blocking(42) == 1764
