@@ -1,13 +1,9 @@
 import pickle
 import pytest
 
-from synchronicity import Synchronizer
+from synchronicity import Interface, Synchronizer
 
 
-s = Synchronizer()
-
-
-@s
 class PicklableClass:
     async def f(self, x):
         return x**2
@@ -15,7 +11,9 @@ class PicklableClass:
 
 @pytest.mark.skip(reason="Let's revisit this in 0.2.0")
 def test_pickle():
-    obj = PicklableClass()
+    s = Synchronizer()
+    BlockingPicklableClass = s.create(PicklableClass, Interface.BLOCKING)
+    obj = BlockingPicklableClass()
     assert obj.f(42) == 1764
     data = pickle.dumps(obj)
     obj2 = pickle.loads(data)
@@ -23,4 +21,5 @@ def test_pickle():
 
 
 def test_pickle_synchronizer():
+    s = Synchronizer()
     pickle.dumps(s)
