@@ -16,3 +16,7 @@ _T_Blocking = synchronizer.create_blocking(
     e2e_example_impl._T, "_T_Blocking", __name__
 )  # synchronize the TypeVar to support translation of bounds
 listify = synchronizer.create_blocking(e2e_example_impl._listify, "listify", __name__)
+
+overloaded = synchronizer.create_blocking(
+    e2e_example_impl._overloaded, "overloaded", __name__
+)
